5 out of 5 stars

#### Crepes on Cole is awesome

Reviewer: Tantek - April 18, 2005

Crepes on Cole is one of the best little creperies in San Francisco. Excellent food and service. Plenty of tables in a variety of sizes for parties large and small. Window seating makes for excellent people watching to/from the N-Judah which stops right outside. I've had many fun social gatherings here, as well as gotten plenty of work done thanks to neighborhood WiFi.

Visit date: April 2005

Food eaten: crepe

Permanent link for review: http://example.com/crepe

Creative Commons Attribution-ShareAlike License